require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_accountpolicy',
  dscmeta_resource_friendly_name: 'AccountPolicy',
  dscmeta_resource_name: 'MSFT_AccountPolicy',
  dscmeta_module_name: 'SecurityPolicyDsc',
  dscmeta_module_version: '2.7.0.0',
  docs: 'The DSC AccountPolicy resource type.
         Automatically generated from version 2.7.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_maximum_password_age: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_password_must_meet_complexity_requirements: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'A unique name of the AccountPolicy resource instance. This is not used during configuration.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maximum_lifetime_for_user_ticket_renewal: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_account_lockout_threshold: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_store_passwords_using_reversible_encryption: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enforce_password_history: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximum_lifetime_for_service_ticket: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_minimum_password_length: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_account_lockout_duration: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximum_tolerance_for_computer_clock_synchronization: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximum_lifetime_for_user_ticket: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_enforce_user_logon_restrictions: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minimum_password_age: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_reset_account_lockout_counter_after: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
