require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_securityoption',
  dscmeta_resource_friendly_name: 'SecurityOption',
  dscmeta_resource_name: 'MSFT_SecurityOption',
  dscmeta_module_name: 'SecurityPolicyDsc',
  dscmeta_module_version: '2.7.0.0',
  docs: 'The DSC SecurityOption resource type.
         Automatically generated from version 2.7.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_network_security_configure_encryption_types_allowed_for_kerberos: {
      type: "Optional[Array[Enum['DES_CBC_CRC', 'DES_CBC_MD5', 'RC4_HMAC_MD5', 'AES128_HMAC_SHA1', 'AES256_HMAC_SHA1']]]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_domain_controller_refuse_machine_account_password_changes: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_allow_local_system_to_use_computer_identity_for_ntlm: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_minimum_session_security_for_ntlm_ssp_based_including_secure_rpc_clients: {
      type: "Optional[Enum['Require NTLMv2 session security', 'Require 128-bit encryption', 'Both options checked']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_named_pipes_that_can_be_accessed_anonymously: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_digitally_sign_secure_channel_data_when_possible: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_digitally_encrypt_secure_channel_data_when_possible: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_digitally_sign_communications_if_client_agrees: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_do_not_store_lan_manager_hash_value_on_next_password_change: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_client_send_unencrypted_password_to_third_party_smb_servers: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_require_strong_windows_2000_or_later_session_key: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_audit_force_audit_policy_subcategory_settings_windows_vista_or_later_to_override_audit_policy_category_settings: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_guest_account_status: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_do_not_allow_anonymous_enumeration_of_sam_accounts_and_shares: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_cryptography_force_strong_key_protection_for_user_keys_stored_on_the_computer: {
      type: "Optional[Enum['User input is not required when new keys are stored and used', 'User is prompted when the key is first used', 'User must enter a password each time they use a key']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_audit_shut_down_system_immediately_if_unable_to_log_security_audits: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_limit_local_account_use_of_blank_passwords_to_console_logon_only: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_behavior_of_the_elevation_prompt_for_standard_users: {
      type: "Optional[Enum['Automatically deny elevation request', 'Prompt for credentials on the secure desktop', 'Prompt for credentials']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_client_digitally_sign_communications_always: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_controller_ldap_server_signing_requirements: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_smart_card_removal_behavior: {
      type: "Optional[Enum['No Action', 'Lock workstation', 'Force logoff', 'Disconnect if a remote Remote Desktop Services session']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_machine_account_lockout_threshold: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_disable_machine_account_password_changes: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_digitally_sign_communications_always: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_audit_audit_the_use_of_backup_and_restore_privilege: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_allow_localsystem_null_session_fallback: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_display_user_information_when_the_session_is_locked: {
      type: "Optional[Enum['User displayname, domain and user names', 'User display name only', 'Do not display user information']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_rename_guest_account: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_shares_that_can_be_accessed_anonymously: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_admin_approval_mode_for_the_built_in_administrator_account: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_ntlm_authentication_in_this_domain: {
      type: "Optional[Enum['Disable', 'Enable for domain accounts to domain servers', 'Enable for domain accounts', 'Enable for domain servers', 'Enable all']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_settings_use_certificate_rules_on_windows_executables_for_software_restriction_policies: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_add_server_exceptions_in_this_domain: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_do_not_display_last_user_name: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_prompt_user_to_change_password_before_expiration: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_server_spn_target_name_validation_level: {
      type: "Optional[Enum['Off', 'Accept if provided by client', 'Required from client']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_shutdown_allow_system_to_be_shut_down_without_having_to_log_on: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_attempt_s4u2self_to_obtain_claim_information: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_sharing_and_security_model_for_local_accounts: {
      type: "Optional[Enum['Classic - Local users authenticate as themselves', 'Guest only - Local users authenticate as Guest']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devices_restrict_cd_rom_access_to_locally_logged_on_user_only: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_cryptography_use_fips_compliant_algorithms_for_encryption_hashing_and_signing: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_let_everyone_permissions_apply_to_anonymous_users: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_only_elevate_executables_that_are_signed_and_validated: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_do_not_require_ctrl_alt_del: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devices_allow_undock_without_having_to_log_on: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_amount_of_idle_time_required_before_suspending_session: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_do_not_allow_anonymous_enumeration_of_sam_accounts: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devices_restrict_floppy_access_to_locally_logged_on_user_only: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_incoming_ntlm_traffic: {
      type: "Optional[Enum['Disabled', 'Enable auditing for domain accounts', 'Enable auditing for all accounts']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_settings_optional_subsystems: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_microsoft_network_server_disconnect_clients_when_logon_hours_expire: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_lan_manager_authentication_level: {
      type: "Optional[Enum['Send LM & NTLM responses', 'Send LM & NTLM - use NTLMv2 session security if negotiated', 'Send NTLM responses only', 'Send NTLMv2 responses only', 'Send NTLMv2 responses only. Refuse LM', 'Send NTLMv2 responses only. Refuse LM & NTLM']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recovery_console_allow_automatic_administrative_logon: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dcom_machine_launch_restrictions_in_security_descriptor_definition_language_sddl_syntax: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_allow_anonymous_sid_name_translation: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_require_domain_controller_authentication_to_unlock_workstation: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Describes the security option to be managed. This could be anything as long as it is unique',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_message_title_for_users_attempting_to_log_on: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_outgoing_ntlm_traffic_to_remote_servers: {
      type: "Optional[Enum['Allow all', 'Deny all domain accounts', 'Deny all accounts']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_force_logoff_when_logon_hours_expire: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_administrator_account_status: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devices_prevent_users_from_installing_printer_drivers: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_objects_require_case_insensitivity_for_non_windows_subsystems: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_maximum_machine_account_password_age: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_detect_application_installations_and_prompt_for_elevation: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_require_smart_card: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_remotely_accessible_registry_paths_and_subpaths: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_minimum_session_security_for_ntlm_ssp_based_including_secure_rpc_servers: {
      type: "Optional[Enum['Require NTLMv2 session security', 'Require 128-bit encryption', 'Both options checked']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_audit_audit_the_access_of_global_system_objects: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_ldap_client_signing_requirements: {
      type: "Optional[Enum['None', 'Negotiate Signing', 'Require Signing']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_virtualize_file_and_registry_write_failures_to_per_user_locations: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_controller_allow_server_operators_to_schedule_tasks: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_shutdown_clear_virtual_memory_pagefile: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_audit_ntlm_authentication_in_this_domain: {
      type: "Optional[Enum['Allow all', 'Audit all', 'Deny all']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_message_text_for_users_attempting_to_log_on: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_only_elevate_uiaccess_applications_that_are_installed_in_secure_locations: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dcom_machine_access_restrictions_in_security_descriptor_definition_language_sddl_syntax: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_run_all_administrators_in_admin_approval_mode: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_allow_uiaccess_applications_to_prompt_for_elevation_without_using_the_secure_desktop: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_rename_administrator_account: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_audit_incoming_ntlm_traffic: {
      type: "Optional[Enum['Disable', 'Deny for domain accounts to domain servers', 'Deny for domain accounts', 'Deny for domain servers', 'Deny all']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_restrict_clients_allowed_to_make_remote_calls_to_sam: {
      type: "Optional[Array[Struct[{
              permission => Optional[Enum['Allow', 'Deny']],
              identity => Optional[String]
            }]]]",
      desc: 'The Permission and Identity required for restricted remote Sam access',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_RestrictedRemoteSamSecurityDescriptor[]',
      mof_is_embedded: true,
    },
    dsc_network_access_restrict_anonymous_access_to_named_pipes_and_shares: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_restrict_ntlm_add_remote_server_exceptions_for_ntlm_authentication: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_machine_inactivity_limit: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_switch_to_the_secure_desktop_when_prompting_for_elevation: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_do_not_allow_storage_of_passwords_and_credentials_for_network_authentication: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_microsoft_network_client_digitally_sign_communications_if_server_agrees: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_user_account_control_behavior_of_the_elevation_prompt_for_administrators_in_admin_approval_mode: {
      type: "Optional[Enum['Elevate without prompting', 'Prompt for credentials on the secure desktop', 'Prompt for consent on the secure desktop', 'Prompt for credentials', 'Prompt for consent', 'Prompt for consent for non-Windows binaries']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accounts_block_microsoft_accounts: {
      type: "Optional[Enum['This policy is disabled', 'Users cant add Microsoft accounts', 'Users cant add or log on with Microsoft accounts']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interactive_logon_number_of_previous_logons_to_cache_in_case_domain_controller_is_not_available: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devices_allowed_to_format_and_eject_removable_media: {
      type: "Optional[Enum['Administrators', 'Administrators and Power Users', 'Administrators and Interactive Users']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domain_member_digitally_encrypt_or_sign_secure_channel_data_always: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_system_objects_strengthen_default_permissions_of_internal_system_objects_eg_symbolic_links: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recovery_console_allow_floppy_copy_and_access_to_all_drives_and_folders: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_security_allow_pku2u_authentication_requests_to_this_computer_to_use_online_identities: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_network_access_remotely_accessible_registry_paths: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
